//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ParentPoint](../index.md)/[Companion](index.md)/[Haneman](-haneman.md)

# Haneman

[common]\
val [Haneman](-haneman.md): [ParentPoint](../index.md)
